addAll method
Add all the attributes to the current style map.
Implementation
void addAll(Iterable<EasyAttribute> attributes) {
for (final EasyAttribute<Object?> attr in attributes) {
add(attr);
}
}
Add all the attributes to the current style map.
void addAll(Iterable<EasyAttribute> attributes) {
for (final EasyAttribute<Object?> attr in attributes) {
add(attr);
}
}