isBlock property
bool
get
isBlock
Whether all the attributes in this style are only for blocks
Implementation
bool get isBlock => values.every((e) => !e.isInline);
Whether all the attributes in this style are only for blocks
bool get isBlock => values.every((e) => !e.isInline);