isInline property
bool
get
isInline
Whether all the attributes in this style are only for characters
Implementation
bool get isInline => values.every((e) => e.isInline);
Whether all the attributes in this style are only for characters
bool get isInline => values.every((e) => e.isInline);