mergeAll method

void mergeAll(
  1. EasyAttributeStyles styles, {
  2. bool autoRemoveExclusives = true,
})

Merge the all the styles into these style container passed and removes it if the value is null or false

Implementation

void mergeAll(
  EasyAttributeStyles styles, {
  bool autoRemoveExclusives = true,
}) {
  for (final EasyAttribute<Object?> attribute in styles.values) {
    merge(
      attribute,
      autoRemoveExclusives: autoRemoveExclusives,
    );
  }
}