insertAfter method
Inserts the given entry after this entry in the linked list.
If the entry is already in a list, it will be unlinked first.
Implementation
@override
void insertAfter(EasyText entry) {
if (entry.list != null) {
entry.unlink();
}
if (!entry._dirty) {
list!.textLength += entry.length;
}
super.insertAfter(entry);
}