list property
The linked list containing this element.
The value is null if this entry is not currently in any list.
Implementation
@override
EasyTextList? get list => super.list as EasyTextList?;
The linked list containing this element.
The value is null if this entry is not currently in any list.
@override
EasyTextList? get list => super.list as EasyTextList?;