tryMerge method

  1. @Deprecated("tryMerge isnt used and will be removed in future releases. Please, use adjust() instead")
void tryMerge()

try to merge this element with adjacents parts if they share the same style.

Implementation

@Deprecated(
    "tryMerge isnt used and will be removed in future releases. Please, use adjust() instead")
void tryMerge() => adjust();