EasyAttributeStyles class
- Available extensions
Constructors
-
EasyAttributeStyles({required Map<
String, EasyAttribute< attributes})Object?> > -
const
- EasyAttributeStyles.empty()
-
EasyAttributeStyles.fromAttribute(EasyAttribute<
Object?> attr) -
EasyAttributeStyles.fromIterable(Iterable<
EasyAttribute< attr)Object?> >
Properties
- align → AlignmentAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter -
attributes
→ Map<
String, EasyAttribute< Object?> > -
final
- bgColor → BackgroundColorAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - blockIndentation → BlockIndentAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - bold → BoldAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - code → InlineCodeAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - codeblock → CodeBlockAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - color → ColorAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - deepClone → EasyAttributeStyles
-
Returns a new instance containing the same attributes
no setter
- dimensions → DimensionsAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - direction → TextDirectionAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - fontFamily → FontFamilyAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - fontSize → FontSizeAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- header → HeaderAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - isBlock → bool
-
Whether all the attributes in this style are only for blocks
no setter
- isEmpty → bool
-
Whether there are available styles
no setter
- isInline → bool
-
Whether all the attributes in this style are only for characters
no setter
- isNotEmpty → bool
-
Whether there no styles available
no setter
- italic → ItalicAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter -
keys
→ Iterable<
String> -
The keys of this EasyAttributeStyles
no setter
- length → int
-
The number of attributes available
no setter
- lineheight → LineheightAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - link → LinkAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - list → ListAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - orderedList → ListAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- script → ScriptAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter -
single
→ EasyAttribute<
Object?> -
no setter
- strikethrough → StrikeAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - todoList → ListAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - underline → UnderlineAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter - unOrderedList → ListAttribute?
-
Available on EasyAttributeStyles, provided by the StylesExtension extension
no setter -
values
→ Iterable<
EasyAttribute< Object?> > -
The values of this EasyAttributeStyles
no setter
Methods
-
add(
EasyAttribute< Object?> attribute) → void - Adds the attribute to the current style map.
-
addAll(
Iterable< EasyAttribute< attributes) → voidObject?> > -
Add all the
attributesto the current style map. -
clearAll(
) → EasyAttributeStyles - Clear all the styles in this container
-
containsKey(
String key) → bool -
Whether these styles contain the
keypassed -
containsValue(
EasyAttribute< Object?> value) → bool -
Whether these styles contain the
valuepassed -
copy(
) → EasyAttributeStyles - Returns a copy of these styles into a new container instance
-
filter(
bool predicate(EasyAttribute< Object?> )) → List<EasyAttribute< Object?> > -
Returns a filtered list of attribute that satisfies to the
predicate -
get(
String key, {Set< String> altKeys = const {}}) → EasyAttribute<Object?> ? -
Returns the attribute that matches with the
keyor thealtKey -
getAll(
Set< String> predicate) → List<EasyAttribute< Object?> > -
Returns a list of attributes that matches with the keys specified in
predicate -
getBlocks(
{bool getOnlyDefaults = false}) → EasyAttributeStyles - Returns all the blocks contained in this EasyAttributeStyles
-
getBlocksExceptHeader(
{bool getOnlyDefaults = false}) → EasyAttributeStyles - Returns all the blocks contained in this EasyAttributeStyles except the header one
-
getByType<
T extends EasyAttribute< (Object?> >{bool filter(EasyAttribute< Object?> )?}) → EasyAttribute<Object?> ? - Returns the attribute that match with the type assigned
-
invert(
) → EasyAttributeStyles - Returns a map version of this styles but designed to invert values
-
merge(
EasyAttribute< Object?> attribute, {bool autoRemoveExclusives = true}) → void -
Merge the
attributeinto these style container and removes it if the value isnullorfalse -
mergeAll(
EasyAttributeStyles styles, {bool autoRemoveExclusives = true}) → void -
Merge the all the styles into these style container
passed and removes it if the value is
nullorfalse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
EasyAttribute< Object?> attribute) → EasyAttributeStyles - Returns a new style container with the new attribute
-
remove(
String key) → bool -
removeAll(
Set< EasyAttribute< attributes) → voidObject?> > -
toJson(
) → Map< String, dynamic> ? -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant EasyAttributeStyles other) → bool -
The equality operator.
override
-
operator [](
String key) → EasyAttribute< Object?> ? -
operator []=(
String key, EasyAttribute< Object?> attr) → void
Static Methods
-
compose(
EasyAttributeStyles a, EasyAttributeStyles b, {bool autoRemoveExclusives = true}) → EasyAttributeStyles - Returns a composed version of two different styles
-
fromJson(
Map< String, dynamic> ? attributes, {EasyAttribute<Object?> ? onUnknownAttribute(String, dynamic)?}) → EasyAttributeStyles