mergeAll method
Merge the all the styles into these style container
passed and removes it if the value is null or false
Implementation
void mergeAll(
EasyAttributeStyles styles, {
bool autoRemoveExclusives = true,
}) {
for (final EasyAttribute<Object?> attribute in styles.values) {
merge(
attribute,
autoRemoveExclusives: autoRemoveExclusives,
);
}
}